@@ -7,3 +7,7 @@ from firstimpression import time
 from firstimpression import xml
 
 from firstimpression import constants
+
+from os.path import join
+
+file.create_directories([join(constants.LOCAL_INTEGRATED_FOLDER, api_name) for api_name in constants.APIS])
